pub(crate) fn load_secrets(location: &PathBuf) -> CliSecretsExpand description
Loads the secrets file, creating an empty one on disk if it doesn’t exist yet.
pub(crate) fn load_secrets(location: &PathBuf) -> CliSecretsLoads the secrets file, creating an empty one on disk if it doesn’t exist yet.